Group Based Policy Style Commandments
===============================================

Read the OpenStack Style Commandments https://docs.openstack.org/hacking/latest/


Group Based Policy Specific Commandments
--------------------------

- [N319] Validate that debug level logs are not translated
- [N320] Validate that LOG messages, except debug ones, have translations
- [N321] Validate that jsonutils module is used instead of json
- [N322] Detect common errors with assert_called_once_with
- [N323] Enforce namespace-less imports for oslo libraries

